pub trait TripleStoreError {
type Error: Debug;
}Expand description
A trait that encapsulates the error type used by other traits in the library.
pub trait TripleStoreError {
type Error: Debug;
}A trait that encapsulates the error type used by other traits in the library.